@@ -134,6 +134,9 @@ const PlaceEntry = new Lang.Class({
     },
 
     _locEquals: function(placeA, placeB) {
+        if (!placeA.location || !placeB.location)
+            return false;
+
         return (placeA.location.latitude === placeB.location.latitude &&
                 placeA.location.longitude === placeB.location.longitude);
     },
@@ -167,7 +170,7 @@ const PlaceEntry = new Lang.Class({
         let place = model.get_value(iter, PlaceStore.Columns.PLACE);
         let type = model.get_value(iter, PlaceStore.Columns.TYPE);
 
-        if (!this._matchRoute && type === PlaceStore.PlaceType.FAVORITE_ROUTE)
+        if (!this._matchRoute && type === PlaceStore.PlaceType.RECENT_ROUTE)
             return false;
 
         if (place !== null)
